*===================================================
*
* CALIBRATING THE MAGNITUDE OF THE COUNTERCYCLICAL 
*  CAPITAL BUFFER USING MARKET-BASED STRESS TESTS
*
*             MAARTEN R.C. VAN OORDT 
*
*     (JOURNAL OF MONEY, CREDIT AND BANKING)
* 
*
*  Purpose:  	Script to estimate the results in the paper
*  Language:	Stata/MP 15.1 for Windows
*  Date:		September 2020
*
*===================================================





***********************************************
*
*       SETUP DATASET
*
***********************************************

*ssc inst groups

cd "C:\jmcb"
import delimited "Data\data.csv", delimiter(",") clear

egen id = group(dscode) 
egen countrynr = group(country)
gen q = substr(quarter,2,2)
egen yyyysq = concat(year q), punct(" ")
gen t = quarterly(yyyysq,"YQ")
format t %tq
sort id t
xtset id t, quarterly

***********************************************





***********************************************
*
* MACRO ECONOMIC CONTROL VARIABLES
*
***********************************************
* Country-specific changes:
* Adding IFRS Dummy for Canada (footnote 16)
gen ifrs = 0
replace ifrs = 1 if country=="canada" & ( t==tq(2011q4) | t==tq(2012q1) | t==tq(2012q2) | t==tq(2012q3) )

* Create values for missing short-term interest rate for US and Australia
replace interbankrate = threemonthinterestrate if country == "united states"
replace interbankrate = threemonthinterestrate if country == "australia" & t<=tq(1990q2)

* Create values for missing real gdp growth for Austria
replace realgdpgrowth = (levelofrealgdp/l4.levelofrealgdp-1)*100 if country == "austria"

* Add euro area interest rates for countries in the euro area
gen euroarea=1 if (country=="austria" | country=="belgium" | country=="france" | country=="germany" | country=="greece" | country=="ireland" | country=="italy" | country=="portugal" | country=="spain" )
bysort t: egen eurothreemonthinterestrate = total(cond(dscode == "euroareadata", threemonthinterestrate, .))
replace eurothreemonthinterestrate=. if eurothreemonthinterestrate==0
bysort t: egen eurolongterminterestrate = total(cond(dscode == "euroareadata", longterminterestrate, .))
replace eurolongterminterestrate=. if longterminterestrate==0
bysort t: egen eurointerbankrate = total(cond(dscode == "euroareadata", interbankrate, .))
replace eurointerbankrate=. if eurointerbankrate==0
replace threemonthinterestrate = eurothreemonthinterestrate if euroarea==1
replace longterminterestrate = eurolongterminterestrate if euroarea==1
replace interbankrate = eurointerbankrate if euroarea==1
drop eurothreemonthinterestrate eurolongterminterestrate eurointerbankrate 
sort id t

* Generate variable for economic region
gen economicregion=country if euroarea==.
replace economicregion="euro area" if euroarea==1

* Generate macro variables in the regression
gen strate = interbankrate/100
gen slopeyieldcurve = (longterminterestrate - interbankrate)/100
gen stockreturns = (sharepriceindex - l4.sharepriceindex)/l4.sharepriceindex
replace realgdpgrowth = realgdpgrowth/100
replace inflation = inflation / 100
gen unemp = harmonisedunemploymentrate/100

* Create variable list with macro-economic control variables
global macrovars1 realgdpgrowth unemp inflation strate slopeyieldcurve stockreturns ifrs
***********************************************




***********************************************
*
* CALCULATE DEPENDENT VARIABLE: THE CAPITAL BUFFER OF BANKS
*
***********************************************
* Generate point-in-time prudential level of capital
* Minimum level of capital
gen minimum_k = 0.045
* Risk-free rate over the simulation period (6 months)
gen rf6m = ((1+interbankrate/100)^0.5-1)
* Calculate point-in-time prudential level of capital in Eq. (9)
gen kQstar = (minimum_k - k * (1-minimum_k)*(lrcovar - rf6m)) / (1 + (1-minimum_k)*rf6m)
* Generate buffer variable used in the regressions
* Calculate the level of the capital buffer in Eq. (1)
gen buffer = k - kQstar

* For the figures and sensitivity analysis:
* Calculate point-in-time prudential level of capital in Eq. (9) with higher and lower minimum level of capital (Senstivity analysis in Table 8)
gen kQstarlow = (minimum_k - 0.015 - k * (1-minimum_k + 0.015)*(lrcovar - rf6m)) / (1 + (1-minimum_k)*rf6m)
gen kQstarhigh = (minimum_k + 0.015 - k * (1-minimum_k - 0.015)*(lrcovar - rf6m)) / (1 + (1-minimum_k)*rf6m)
* Calculate the level of the capital buffer in Eq. (1) with higher and lower minimum level of capital (Senstivity analysis in Table 8)
gen buffer_highk = k - kQstarhigh
gen buffer_lowk = k - kQstarlow
* Calculations based on alternative assumptions (displayed in Figure 2).
* Panel (a): Before correction for leverage
gen kQ = minimum_k/(1+(1-minimum_k)*lrcovar)
* Panel (b): Based on expected loss
gen kEstar = (minimum_k - k * (1-minimum_k)*(-lrmes - rf6m)) / (1 + (1-minimum_k)*rf6m)
***********************************************





***********************************************
*
* BANK-SPECIFIC CONTROL VARIABLES
*
***********************************************
* Generate bank-specific variables
gen assetgrowth = bvta/l4.bvta - 1
egen allassets = total(bvta) , by(t economicregion)
gen assetshare = bvta/allassets
egen hhi = total(assetshare^2) , by(t economicregion)

* Create variable list with bank-specific control variables
global bankvars1 equitytoassets nni2revenue cashtoassets loanstoassets dfg assetshare hhi
***********************************************





***********************************************
*
* MACROFINANCIAL INDICATORS: GROWTH LEVELS
*
***********************************************
gen credittogdpgrowth = (credittogdpratio - l4.credittogdpratio)/l4.credittogdpratio
gen bankcredittogdpgrowth = (bankcredittogdp - l4.bankcredittogdp)/l4.bankcredittogdp
gen housepricegrowth = (residentialpropertyprices - l4.residentialpropertyprices)/l4.residentialpropertyprices
***********************************************




***********************************************
*
* MACROFINANCIAL INDICATORS: ROLLING-WINDOW PERCENTILES
*
***********************************************
* Generate different indicators of macro-fianncial conditions
g rank_credittogdpgrowth = .  
g rank_bankcredittogdpgrowth = .
g rank_housepricegrowth = .
g rank_credittogdpgrowth_nobs = .  
g rank_bankcredittogdpgrowth_nobs = .
g rank_housepricegrowth_nobs = .
loc d = 365*12 //Set window length for rolling-window percentiles
su date, meanonly
quietly forval n = `r(min)'/`r(max)' {
    count if date == `n'
    if r(N) {
        tempvar i1 j1 i2 j2 i3 j3
        egen `i1' = rank(credittogdpgrowth) if inrange(date, `n' - `d' + 1, `n'), track by(id)
		egen `i2' = rank(bankcredittogdpgrowth) if inrange(date, `n' - `d' + 1, `n'), track by(id)
        egen `i3' = rank(housepricegrowth) if inrange(date, `n' - `d' + 1, `n'), track by(id)
       replace rank_credittogdpgrowth = `i1' if date == `n'
	   replace rank_bankcredittogdpgrowth = `i2' if date == `n'
	   replace rank_housepricegrowth = `i3' if date == `n'
        egen `j1' = count(credittogdpgrowth) if inrange(date, `n' - `d' + 1, `n'), by(id)
		egen `j2' = count(bankcredittogdpgrowth) if inrange(date, `n' - `d' + 1, `n'), by(id)
		egen `j3' = count(housepricegrowth) if inrange(date, `n' - `d' + 1, `n'), by(id) 
       replace rank_credittogdpgrowth_nobs = `j1' if date == `n'
	   replace rank_bankcredittogdpgrowth_nobs = `j2' if date == `n'
	   replace rank_housepricegrowth_nobs = `j3' if date == `n'
         drop `i1' `j1' `i2' `j2' `i3' `j3'
    }    
}
gen perc_credittogdpgrowth = (rank_credittogdpgrowth + 0.5)/rank_credittogdpgrowth_nobs if rank_credittogdpgrowth_nobs>=40
gen perc_bankcredittogdpgrowth = (rank_bankcredittogdpgrowth + 0.5)/rank_bankcredittogdpgrowth_nobs if rank_bankcredittogdpgrowth_nobs>=40
gen perc_housepricegrowth = (rank_housepricegrowth + 0.5)/rank_housepricegrowth_nobs if rank_housepricegrowth_nobs>=40
***********************************************





***********************************************
*
* SAMPLE SELECTION
*
***********************************************
egen maxequitytoassets = max(equitytoassets), by(id)
gen beforeeuro=1 if economicregion=="euro area" & t<tq(1999q1)
gen somefin = 1 if bankcredittogdpgrowth !=. | credittogdpgrowth !=. | housepricegrowth !=.
* Select observations of banks with at least 40 bank-quarter observations available in regression (Section 4), 
* with asset growth less than 50 percent (footnote 12), with a maximum equity-to-assets ratio of less than 25 
* percent (appendix A), and where the period for banks in the euro area starts in 1999 (Figure 3).
xtreg buffer kQstar $macrovars1 $bankvars1 somefin i.id if t<=tq(2016q4) & maxequitytoassets<0.25 & assetgrowth<0.5 & beforeeuro!=1, fe
gen thesample = e(sample)
egen numberofobs = total(thesample), by(id)
gen selectsample=1 if numberofobs>=40 & thesample
***********************************************





***********************************************
*
*       Figure 2: Point-in-Time Prudent Capital Ratios of Canadian banks
*
***********************************************
* Generate country-level averages
egen double aggregateassets = total(bvta) if selectsample==1, by(t economicregion)
egen double ave_k = total(bvta*k*100/aggregateassets) if selectsample==1, by(t economicregion)
egen double ave_kQ = total(bvta*kQ*100/aggregateassets) if selectsample==1, by(t economicregion)
egen double ave_kQstar = total(bvta*kQstar*100/aggregateassets) if selectsample==1, by(t economicregion)
egen double ave_kEstar = total(bvta*kEstar*100/aggregateassets) if selectsample==1, by(t economicregion)
gen ave_minimum_k = 100 * minimum_k
gen ave_buffer = (ave_k - ave_kQstar) / 100

* Chart 2(a) in the paper
twoway (line ave_kQ t if dscode=="C:TD", sort lcolor(navy) lwidth(medthick) lpattern(solid)) (line ave_kQstar t if dscode=="C:TD", sort lcolor(midgreen) lwidth(medthick) lpattern(solid)) (line ave_k t if dscode=="C:TD", sort lcolor(ltblue) lwidth(medium) lpattern(solid)) (line ave_minimum_k t, sort lcolor(red) lwidth(medthin) lpattern(dash)) if t>=tq(2000q1) & t<=tq(2016q4), ylabel(0(4)18, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall)) legend(on order(1 "Prudent level (before correction for leverage effect)" 2 "Prudent level (after correction for leverage effect)" 3 "Observed market-based capital ratio") rows(3) size(small) region(fcolor(gs15))) xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig2a.eps, replace

* Chart 2(b) in the paper
twoway (line ave_kEstar t if dscode=="C:TD", sort lcolor(orange) lwidth(medthick) lpattern(solid)) (line ave_kQstar t if dscode=="C:TD", sort lcolor(midgreen) lwidth(medthick) lpattern(solid)) (line ave_k t if dscode=="C:TD", sort lcolor(ltblue) lwidth(medium) lpattern(solid)) (line ave_minimum_k t, sort lcolor(red) lwidth(medthin) lpattern(dash)) if t>=tq(2000q1) & t<=tq(2016q4), ylabel(0(4)18, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall)) legend(on order(1 "Prudent level (based on the expected loss)" 2 "Prudent level (based on admissible failure probability)" 3 "Observed market-based capital ratio") rows(3) size(small) region(fcolor(gs15))) xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig2b.eps, replace
***********************************************





***********************************************
*
*       Table 1: Descriptive Statistics
*
***********************************************
* Summary statistics and list of banks
xtreg buffer somefin $macrovars1 $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
tabstat credittogdpgrowth bankcredittogdpgrowth housepricegrowth buffer k kQstar $macrovars1 $bankvars1 if e(sample), stats(mean sd p10 p90 n) columns(statistics)
***********************************************





***********************************************
*
*       Table 2: Correlations of Market-Based Capital Buffers with Other Risk Measures
*
***********************************************
* Column 1
corr kQstar sriskcorr if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr kQstar mes if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr kQstar syslink if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr kQstar tailbeta if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr kQstar dd if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
* Column 2
cluster2 kQstar sriskcorr if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 kQstar mes if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 kQstar syslink if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 kQstar tailbeta if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 kQstar dd if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
* Column 3
corr buffer sriskcorr if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr buffer mes if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr buffer syslink if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr buffer tailbeta if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
corr buffer dd if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
* Column 4
cluster2 buffer sriskcorr if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 buffer mes if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 buffer syslink if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 buffer tailbeta if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
cluster2 buffer dd if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4), fcluster(id) tcluster(t)
***********************************************





***********************************************
*
*       Table 3: Correlations of Market-Based Capital Buffers with Macro-Financial Conditions
*
***********************************************
* Generate demeaned variables
regress buffer i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) 
predict temp if e(sample)
gen dem_buffer = buffer - temp
drop temp
regress credittogdpgrowth i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) 
predict temp if e(sample)
gen dem_credittogdpgrowth = credittogdpgrowth - temp
drop temp
regress bankcredittogdpgrowth i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) 
predict temp if e(sample)
gen dem_bankcredittogdpgrowth = bankcredittogdpgrowth - temp
drop temp
regress housepricegrowth i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) 
predict temp if e(sample)
gen dem_housepricegrowth = housepricegrowth - temp
drop temp
regress perc_credittogdpgrowth i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) 
predict temp if e(sample)
gen dem_perc_credittogdpgrowth = perc_credittogdpgrowth - temp
drop temp
regress perc_bankcredittogdpgrowth i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) 
predict temp if e(sample)
gen dem_perc_bankcredittogdpgrowth = perc_bankcredittogdpgrowth - temp
drop temp
regress perc_housepricegrowth i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) 
predict temp if e(sample)
gen dem_perc_housepricegrowth = perc_housepricegrowth - temp
drop temp

* Estimate simple correlations
*Panel (a), column 1
corr buffer l12.dem_credittogdpgrowth l8.dem_credittogdpgrowth l4.dem_credittogdpgrowth dem_credittogdpgrowth f4.dem_credittogdpgrowth f8.dem_credittogdpgrowth f12.dem_credittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
*Panel (a), column 2
corr buffer l12.dem_bankcredittogdpgrowth l8.dem_bankcredittogdpgrowth l4.dem_bankcredittogdpgrowth dem_bankcredittogdpgrowth f4.dem_bankcredittogdpgrowth f8.dem_bankcredittogdpgrowth f12.dem_bankcredittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
*Panel (a), column 3
corr buffer l12.dem_housepricegrowth l8.dem_housepricegrowth l4.dem_housepricegrowth dem_housepricegrowth f4.dem_housepricegrowth f8.dem_housepricegrowth f12.dem_housepricegrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
*Panel (b), column 1
corr buffer l12.dem_perc_credittogdpgrowth l8.dem_perc_credittogdpgrowth l4.dem_perc_credittogdpgrowth dem_perc_credittogdpgrowth f4.dem_perc_credittogdpgrowth f8.dem_perc_credittogdpgrowth f12.dem_perc_credittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
*Panel (b), column 2
corr buffer l12.dem_perc_bankcredittogdpgrowth l8.dem_perc_bankcredittogdpgrowth l4.dem_perc_bankcredittogdpgrowth dem_perc_bankcredittogdpgrowth f4.dem_perc_bankcredittogdpgrowth f8.dem_perc_bankcredittogdpgrowth f12.dem_perc_bankcredittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
*Panel (b), column 3
corr buffer l12.dem_perc_housepricegrowth l8.dem_perc_housepricegrowth l4.dem_perc_housepricegrowth dem_perc_housepricegrowth f4.dem_perc_housepricegrowth f8.dem_perc_housepricegrowth f12.dem_perc_housepricegrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)
***********************************************







***********************************************
*
*       Figure 3: Evolution of Market-Based Capital Buffers
*
***********************************************
* Generate country medians of the capital buffer variable
egen double mdn_buffer = median(buffer*100) if selectsample==1, by(t economicregion)
bysort t: egen mdn_buffereuro = mean(cond(economicregion == "euro area", mdn_buffer, .))
replace mdn_buffer = mdn_buffereuro if dscode=="euroareadata"
sort id t

* Generate Figure 3
twoway (line mdn_buffer t if t>=tq(1990q1) & t<tq(2016q4), sort lcolor(navy) lwidth(medthick) lpattern(solid)) if economicregion=="australia" & t>=tq(1990q1) & t<tq(2016q4), ylabel(-6(2)6, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) ytitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall))  xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig3aus.eps, replace
twoway (line mdn_buffer t if t>=tq(1990q1) & t<tq(2016q4), sort lcolor(navy) lwidth(medthick) lpattern(solid)) if economicregion=="canada"    & t>=tq(1990q1) & t<tq(2016q4), ylabel(-6(2)6, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) ytitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall))  xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig3can.eps, replace
twoway (line mdn_buffer t if t>=tq(1990q1) & t<tq(2016q4), sort lcolor(navy) lwidth(medthick) lpattern(solid)) if dscode=="euroareadata" & t>=tq(1990q1) & t<tq(2016q4), ylabel(-6(2)6, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) ytitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall))  xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig3eur.eps, replace
twoway (line mdn_buffer t if t>=tq(1990q1) & t<tq(2016q4), sort lcolor(navy) lwidth(medthick) lpattern(solid)) if economicregion=="japan" & t>=tq(1990q1) & t<tq(2016q4), ylabel(-6(2)6, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) ytitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall))  xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig3jap.eps, replace
twoway (line mdn_buffer t if t>=tq(1990q1) & t<tq(2016q4), sort lcolor(navy) lwidth(medthick) lpattern(solid)) if economicregion=="united kingdom" & t>=tq(1990q1) & t<tq(2016q4), ylabel(-6(2)6, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) ytitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall))  xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig3uk.eps, replace
twoway (line mdn_buffer t if t>=tq(1990q1) & t<tq(2016q4), sort lcolor(navy) lwidth(medthick) lpattern(solid)) if economicregion=="united states" & t>=tq(1990q1) & t<tq(2016q4), ylabel(-6(3)9, labsize(medsmall) format(%ty)) xtitle(, size(zero) margin(zero)) ytitle(, size(zero) margin(zero)) xlabel(, labsize(medsmall))  xsize(4) ysize(4) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(gs15) lcolor(gs15) ifcolor(none) ilcolor(none))
graph export Results\fig3us.eps, replace
***********************************************





***********************************************
*
*       Table 4: Macro-financial Conditions and the Capital Buffers of Banks (without Macro-Economic Controls)
*
***********************************************
xtreg buffer credittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table4.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table4.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table4.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table4.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table4.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table4.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************





***********************************************
*
*       Table 5: Macro-financial Conditions and the Capital Buffers of Banks (with Macro-Economic Controls)
*
***********************************************
xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table5.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table5.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table5.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table5.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table5.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table5.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************





***********************************************
*
*       Table 6: Macro-financial Conditions and the Capital Buffers of Banks (4 Quarters Leading Signal)
*
***********************************************
* Create lagged variables
gen L4credittogdpgrowth = l4.credittogdpgrowth
gen L4bankcredittogdpgrowth = l4.bankcredittogdpgrowth
gen L4housepricegrowth = l4.housepricegrowth
gen L4perc_credittogdpgrowth = l4.perc_credittogdpgrowth
gen L4perc_bankcredittogdpgrowth = l4.perc_bankcredittogdpgrowth
gen L4perc_housepricegrowth = l4.perc_housepricegrowth

* International table, bank-specific and macro-economic controls with 4 LAGS
xtreg buffer l4.credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer L4credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table6.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(L4credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer l4.perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer L4perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table6.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(L4perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer l4.bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer L4bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table6.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(L4bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer l4.perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer L4perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table6.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(L4perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer l4.housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer L4housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table6.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(L4housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer l4.perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer L4perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table6.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(L4perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************






***********************************************
*
*       Table 7, panel (a): Only data prior to the 2007-09 crisis (sample from 1990Q1 until 2007Q2)
*
***********************************************
* Summary statistics
xtreg buffer somefin $macrovars1 $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fe
tabstat buffer credittogdpgrowth bankcredittogdpgrowth housepricegrowth if e(sample), stats(p10 p90) columns(statistics)

xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fcluster(id) tcluster(t)
outreg2 using Results\table7a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fcluster(id) tcluster(t)
outreg2 using Results\table7a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fcluster(id) tcluster(t)
outreg2 using Results\table7a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fcluster(id) tcluster(t)
outreg2 using Results\table7a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fcluster(id) tcluster(t)
outreg2 using Results\table7a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2007q2) , fcluster(id) tcluster(t)
outreg2 using Results\table7a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************


***********************************************
*
*       Table 7, panel (b): Excluding banking crises (as identified by Laeven and Valencia, 2018)
*
***********************************************
* Summary statistics
gen laevenvalencia = 0
replace laevenvalencia = 1 if country=="japan" & t>=tq(1997q4) & t<=tq(2001q4)
replace laevenvalencia = 1 if country=="austria" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="belgium" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="france" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="germany" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="greece" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="ireland" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="italy" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="portugal" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="spain" & t>=tq(2008q3) & t<=tq(2012q4)
replace laevenvalencia = 1 if country=="united states" & t>=tq(2007q4) & t<=tq(2011q4)
replace laevenvalencia = 1 if country=="united kingdom" & t>=tq(2007q4) & t<=tq(2011q4)

xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fcluster(id) tcluster(t)
outreg2 using Results\table7b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fcluster(id) tcluster(t)
outreg2 using Results\table7b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fcluster(id) tcluster(t)
outreg2 using Results\table7b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fcluster(id) tcluster(t)
outreg2 using Results\table7b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fcluster(id) tcluster(t)
outreg2 using Results\table7b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & laevenvalencia!=1 , fcluster(id) tcluster(t)
outreg2 using Results\table7b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************


***********************************************
*
*      Table 7, panel (c): Excluding periods with negative growth
*
***********************************************
* Summary statistics
xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & realgdpgrowth>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95)
***********************************************


***********************************************
*
*       Table 7, panel (d): Excluding periods with inverted yield curves
*
***********************************************
* Summary statistics
xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & slopeyieldcurve>=0 , fcluster(id) tcluster(t)
outreg2 using Results\table7d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95)
***********************************************


***********************************************
*
*       Table 7, panel (e): Controlling for Sovereign Risk
*
***********************************************
replace govbudgetbalance=govbudgetbalance/100
replace totalcredittogovtsector=totalcredittogovtsector/100

*Note: the variable in regression is budget balance, while table in paper reports coefficient for budget deficit (hence: coefficient budget balance * -1)
global gov1 govbudgetbalance totalcredittogovtsector

xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table7e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth $gov1 ) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table7e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth $gov1 ) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table7e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth $gov1 ) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table7e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth $gov1 ) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer housepricegrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table7e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth $gov1 ) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 $gov1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table7e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth $gov1 ) nocons label  addstat(R-sq, $model_r2) level(95) 

replace govbudgetbalance=govbudgetbalance*100
replace totalcredittogovtsector=totalcredittogovtsector*100
***********************************************





***********************************************
*
*       Table 8, panel (a): Sensitivity analysis with low k (3 percent)
*
***********************************************
xtreg buffer_lowk credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_lowk credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer_lowk perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_lowk perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_lowk bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_lowk bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_lowk perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_lowk perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_lowk housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_lowk housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_lowk perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_lowk perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8a.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************


***********************************************
*
*       Table 8, panel (b): Sensitivity analysis with high k (6 percent)
*
***********************************************
xtreg buffer_highk credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_highk credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer_highk perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_highk perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_highk bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_highk bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_highk perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_highk perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_highk housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_highk housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer_highk perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer_highk perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8b.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************


***********************************************
*
*       Table 8, panel (c): Longer time window (sample from 1980Q1 until 2016Q4)
*
***********************************************
xtreg buffer somefin $macrovars1 $bankvars1 i.id if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fe
tabstat buffer credittogdpgrowth bankcredittogdpgrowth housepricegrowth if e(sample), stats(p10 p90) columns(statistics)

xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fe
gen insample= 1 if e(sample)
egen number = count(insample) , by(t country)
scatter number t if t>tq(1980q1), by(country) type(line)
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1980q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table8c.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************


***********************************************
*
*       Table 8, panel (d): Region-level data (medians)
*
***********************************************
*Generate medians of all bank-specific variables
egen double mdn_equitytoassets = median(equitytoassets) if selectsample==1, by(t economicregion)
egen double mdn_nni2revenue = median(nni2revenue) if selectsample==1, by(t economicregion)
egen double mdn_cashtoassets = median(cashtoassets) if selectsample==1, by(t economicregion)
egen double mdn_loanstoassets = median(loanstoassets) if selectsample==1, by(t economicregion)
egen double mdn_dfg  = median(dfg) if selectsample==1, by(t economicregion)
egen double mdn_assetshare = median(assetshare) if selectsample==1, by(t economicregion)

* Select one bank without missing observations for every country US / UK / Japan / Canada / euro area / australia
global bankvars1mdn mdn_equitytoassets mdn_nni2revenue mdn_cashtoassets mdn_loanstoassets mdn_dfg mdn_assetshare hhi
gen mdn_select = 1 if dscode=="U:BOH" | dscode=="BARC" | dscode=="J:CHBK" | dscode=="C:TD" | dscode=="euroareadata" | dscode=="A:NABX"
* All banks in the UK have some missing observations. To deal with few missing observations
bysort t: egen mdn_buffer_uk = mean(cond(country == "united kingdom", mdn_buffer, .))
replace mdn_buffer = mdn_buffer_uk if dscode=="BARC"
bysort t: egen mdn_equitytoassets_uk = mean(cond(country == "united kingdom", mdn_equitytoassets, .))
replace mdn_equitytoassets = mdn_equitytoassets_uk if dscode=="BARC"
bysort t: egen mdn_nni2revenue_uk = mean(cond(country == "united kingdom", mdn_nni2revenue, .))
replace mdn_nni2revenue = mdn_nni2revenue_uk if dscode=="BARC"
bysort t: egen mdn_cashtoassets_uk = mean(cond(country == "united kingdom", mdn_cashtoassets, .))
replace mdn_cashtoassets = mdn_cashtoassets_uk if dscode=="BARC"
bysort t: egen mdn_loanstoassets_uk = mean(cond(country == "united kingdom", mdn_loanstoassets, .))
replace mdn_loanstoassets = mdn_loanstoassets_uk if dscode=="BARC"
bysort t: egen mdn_dfg_uk = mean(cond(country == "united kingdom", mdn_dfg, .))
replace mdn_dfg = mdn_dfg_uk if dscode=="BARC"
bysort t: egen mdn_assetshare_uk = mean(cond(country == "united kingdom", mdn_assetshare, .))
replace mdn_assetshare = mdn_assetshare_uk if dscode=="BARC"
drop mdn_buffer_uk mdn_equitytoassets_uk mdn_nni2revenue_uk mdn_cashtoassets_uk mdn_loanstoassets_uk mdn_dfg_uk mdn_assetshare_uk
sort id t

* Add euro area medians to euro area data
bysort t: egen mdn_equitytoassetseuro = mean(cond(economicregion == "euro area", mdn_equitytoassets, .))
replace mdn_equitytoassets = mdn_equitytoassetseuro if dscode=="euroareadata"
bysort t: egen mdn_nni2revenueeuro = mean(cond(economicregion == "euro area", mdn_nni2revenue, .))
replace mdn_nni2revenue = mdn_nni2revenueeuro if dscode=="euroareadata"
bysort t: egen mdn_cashtoassetseuro = mean(cond(economicregion == "euro area", mdn_cashtoassets, .))
replace mdn_cashtoassets = mdn_cashtoassetseuro if dscode=="euroareadata"
bysort t: egen mdn_loanstoassetseuro = mean(cond(economicregion == "euro area", mdn_loanstoassets, .))
replace mdn_loanstoassets = mdn_loanstoassetseuro if dscode=="euroareadata"
bysort t: egen mdn_dfgeuro = mean(cond(economicregion == "euro area", mdn_dfg, .))
replace mdn_dfg = mdn_dfgeuro if dscode=="euroareadata"
bysort t: egen mdn_assetshareeuro = mean(cond(economicregion == "euro area", mdn_assetshare, .))
replace mdn_assetshare = mdn_assetshareeuro if dscode=="euroareadata"
drop mdn_buffereuro mdn_equitytoassetseuro mdn_nni2revenueeuro mdn_cashtoassetseuro mdn_loanstoassetseuro mdn_dfgeuro mdn_assetshareeuro
sort id t

* Summary statistics 
replace mdn_buffer = mdn_buffer/100
xtreg mdn_buffer somefin $macrovars1 $bankvars1 i.id if mdn_select==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
tabstat mdn_buffer credittogdpgrowth bankcredittogdpgrowth housepricegrowth if e(sample), stats(p10 p90) columns(statistics)

xtreg mdn_buffer credittogdpgrowth $macrovars1 $bankvars1mdn i.t if mdn_select==1 & t>=tq(1990q1) & t<tq(2016q4), fe robust
global model_r2 = e(r2_w)
outreg2 using Results\table8d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg mdn_buffer perc_credittogdpgrowth $macrovars1 $bankvars1mdn i.t if mdn_select==1 & t>=tq(1990q1) & t<tq(2016q4), fe robust
global model_r2 = e(r2_w)
outreg2 using Results\table8d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg mdn_buffer bankcredittogdpgrowth $macrovars1 $bankvars1mdn i.t if mdn_select==1 & t>=tq(1990q1) & t<tq(2016q4), fe robust
global model_r2 = e(r2_w)
outreg2 using Results\table8d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg mdn_buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1mdn i.t if mdn_select==1 & t>=tq(1990q1) & t<tq(2016q4), fe robust
global model_r2 = e(r2_w)
outreg2 using Results\table8d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95)

xtreg mdn_buffer housepricegrowth $macrovars1 $bankvars1mdn i.t if mdn_select==1 & t>=tq(1990q1) & t<tq(2016q4), fe robust
global model_r2 = e(r2_w)
outreg2 using Results\table8d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95)

xtreg mdn_buffer perc_housepricegrowth $macrovars1 $bankvars1mdn i.t if mdn_select==1 & t>=tq(1990q1) & t<tq(2016q4), fe robust
global model_r2 = e(r2_w)
outreg2 using Results\table8d.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
replace mdn_buffer = mdn_buffer*100
***********************************************


***********************************************
*
*       Table 8, panel (e): Bank-specific trends
*
***********************************************
xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id#c.t i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
outreg2 using Results\table8e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id#c.t i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
outreg2 using Results\table8e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id#c.t i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
outreg2 using Results\table8e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id#c.t i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
outreg2 using Results\table8e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id#c.t i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
outreg2 using Results\table8e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id#c.t i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
outreg2 using Results\table8e.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************


***********************************************
*
*       Table 8, panel (g): Excluding internationally-focused banks
*
***********************************************
* Add GSIB disclosure data
run "gsibdata.do"

xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fcluster(id) tcluster(t)
outreg2 using Results\table8g.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fcluster(id) tcluster(t)
outreg2 using Results\table8g.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fcluster(id) tcluster(t)
outreg2 using Results\table8g.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fcluster(id) tcluster(t)
outreg2 using Results\table8g.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fcluster(id) tcluster(t)
outreg2 using Results\table8g.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) & (int_claims<0.40 | int_claims==.), fcluster(id) tcluster(t)
outreg2 using Results\table8g.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************





***********************************************
*
*       Table 9: Alternative credit measures (credit-to-gdp-gap and real credit growth)
*
***********************************************
replace credittogdpgap = credittogdpgap /100
replace credittogdpgap = . if credittogdpgap==0
gen realcreditgrowth = (credittogdpratio / L4.credittogdpratio) * (1 + realgdpgrowth) / ( ((1+inflation)^0.25)*((1+L.inflation)^0.25)*((1+L2.inflation)^0.25)*((1+L3.inflation)^0.25) ) - 1

* International table, bank, but no macro-economic controls 
xtreg buffer credittogdpgap $bankvars1 if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
tabstat buffer k kQstar credittogdpgap if e(sample), stats(mean p50 sd p10 p90 n) columns(statistics)
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgap $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table9.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgap ) nocons label  addstat(R-sq, $model_r2) level(95) replace

* International table, bank and macro-economic controls 
xtreg buffer credittogdpgap $macrovars1 $bankvars1 i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgap $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table9.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgap ) nocons label  addstat(R-sq, $model_r2) level(95) 

* International table, bank, but no macro-economic controls 
xtreg buffer realcreditgrowth $bankvars1 if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
tabstat buffer k kQstar realcreditgrowth if e(sample), stats(mean p50 sd p10 p90 n) columns(statistics)
global model_r2 = e(r2_w)
xi: cluster2 buffer realcreditgrowth $bankvars1 i.id if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table9.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(realcreditgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

* International table, bank and macro-economic controls 
xtreg buffer realcreditgrowth $macrovars1 $bankvars1 i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer realcreditgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\table9.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(realcreditgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************





***********************************************
*
*       Table 10: List of Banks
*
***********************************************
groups country name dscode if selectsample==1
***********************************************





***********************************************
*
*      ONLINE APPENDIX: Table 1 - Macro-financial Conditions and the Capital Buffers of Banks with all Controls
*
***********************************************
xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
outreg2 using Results\tableapp1.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth $macrovars1 $bankvars1 ) nocons label  level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
outreg2 using Results\tableapp1.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth $macrovars1 $bankvars1 ) nocons label   level(95) 


xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
outreg2 using Results\tableapp1.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth $macrovars1 $bankvars1 ) nocons label  level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
outreg2 using Results\tableapp1.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth $macrovars1 $bankvars1 ) nocons label  level(95) 


xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
outreg2 using Results\tableapp1.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth $macrovars1 $bankvars1 ) nocons label level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
outreg2 using Results\tableapp1.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth $macrovars1 $bankvars1 ) nocons label   level(95) 
***********************************************



***********************************************
*
*      ONLINE APPENDIX: Table 2 - Macro-financial Conditions and the Capital Buffers of Banks with all Controls
*
***********************************************
xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tableapp2.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth $macrovars1 $bankvars1 ) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tableapp2.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth $macrovars1 $bankvars1 ) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tableapp2.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth $macrovars1 $bankvars1 ) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tableapp2.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth $macrovars1 $bankvars1 ) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tableapp2.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth $macrovars1 $bankvars1 ) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tableapp2.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth $macrovars1 $bankvars1 ) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************





***********************************************
*
*       Footnote 7: Results supporting the remark on using a stricter criterion on asset growth
*
***********************************************
gen selectsample_ma=1 if selectsample==1 & assetgrowth<0.25

xtreg buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tablefn7.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) replace

xtreg buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t  if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tablefn7.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tablefn7.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tablefn7.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label  addstat(R-sq, $model_r2) level(95) 


xtreg buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tablefn7.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 

xtreg buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fe
global model_r2 = e(r2_w)
xi: cluster2 buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t if selectsample_ma==1 & t>=tq(1990q1) & t<=tq(2016q4) , fcluster(id) tcluster(t)
outreg2 using Results\tablefn7.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label  addstat(R-sq, $model_r2) level(95) 
***********************************************





***********************************************
*
*       Table 8, panel (f): Random-slope Model
*
***********************************************
* Estimation of this panel is computation-intensive (i.e., may take long)
xtmixed buffer credittogdpgrowth $macrovars1 $bankvars1 i.id i.t || id: credittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , vce(robust)
outreg2 using Results\table8f.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(credittogdpgrowth) nocons label level(95) replace
xtmixed buffer perc_credittogdpgrowth $macrovars1 $bankvars1 i.id i.t || id: perc_credittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , vce(robust)
outreg2 using Results\table8f.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_credittogdpgrowth) nocons label level(95) 
xtmixed buffer bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t || id: bankcredittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4)  , vce(robust)
outreg2 using Results\table8f.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(bankcredittogdpgrowth) nocons label level(95) 
xtmixed buffer perc_bankcredittogdpgrowth $macrovars1 $bankvars1 i.id i.t || id: perc_bankcredittogdpgrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , vce(robust)
outreg2 using Results\table8f.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_bankcredittogdpgrowth) nocons label level(95) 
xtmixed buffer housepricegrowth $macrovars1 $bankvars1 i.id i.t || id: housepricegrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , vce(robust)
outreg2 using Results\table8f.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(housepricegrowth) nocons label level(95) 
xtmixed buffer perc_housepricegrowth $macrovars1 $bankvars1 i.id i.t || id: perc_housepricegrowth if selectsample==1 & t>=tq(1990q1) & t<=tq(2016q4) , vce(robust)
outreg2 using Results\table8f.xls, stats(coef se ci) cttop(all) bdec(3) sdec(3) keep(perc_housepricegrowth) nocons label level(95) 
***********************************************